tiled.client.sparse.SparseClient
================================

.. currentmodule:: tiled.client.sparse

.. autoclass:: SparseClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SparseClient.__init__
      ~SparseClient.download
      ~SparseClient.export
      ~SparseClient.login
      ~SparseClient.logout
      ~SparseClient.new_variation
      ~SparseClient.read
      ~SparseClient.read_block
      ~SparseClient.refresh
      ~SparseClient.structure
      ~SparseClient.todense
      ~SparseClient.update_metadata
      ~SparseClient.write
      ~SparseClient.write_block
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SparseClient.chunks
      ~SparseClient.context
      ~SparseClient.dims
      ~SparseClient.formats
      ~SparseClient.item
      ~SparseClient.metadata
      ~SparseClient.metadata_revisions
      ~SparseClient.ndim
      ~SparseClient.offline
      ~SparseClient.references
      ~SparseClient.shape
      ~SparseClient.specs
      ~SparseClient.uri
   
   